# core

This subpackage contains the code to build the `cellprofiler-core` package. It contains the critical classes and components required by the [CellProfiler](https://cellprofiler.org) software, whereas the [frontend](https://github.com/CellProfiler/CellProfiler/tree/main/src/frontend) contains non-essential modules and the GUI interface. This package can be used in isolation, separate from the frontend, to access CellProfiler's functionality as a Python package, see [this page](https://github.com/CellProfiler/CellProfiler/wiki/CellProfiler-as-a-Python-package) for more details.
